@@ -81,9 +81,8 @@ set dataInterfaces_file [open ../${::AIT::name_Project}.datainterfaces.txt "w"]
 set bd_addr_segments [list \
     [dict create name cmdInQueue bd_seg_name Hardware_Runtime/cmdInQueue_BRAM_Ctrl/S_AXI/Mem0 size [expr ${::AIT::cmdInSubqueue_len}*${::AIT::num_accs}*8]] \
     [dict create name cmdOutQueue bd_seg_name Hardware_Runtime/cmdOutQueue_BRAM_Ctrl/S_AXI/Mem0 size [expr ${::AIT::cmdOutSubqueue_len}*${::AIT::num_accs}*8]] \
-    [dict create name hwruntime_rst bd_seg_name Hardware_Runtime/hwruntime_rst/S_AXI/Reg size 4096] \
 ]
-if {${::AIT::advanced_hwruntime} && ${::AIT::enable_spawn_queues}} {
+if ${::AIT::enable_spawn_queues} {
     lappend bd_addr_segments [dict create name spawnInQueue bd_seg_name Hardware_Runtime/spawnInQueue_BRAM_Ctrl/S_AXI/Mem0 size [expr ${::AIT::spawnInQueue_len}*8]]
     lappend bd_addr_segments [dict create name spawnOutQueue bd_seg_name Hardware_Runtime/spawnOutQueue_BRAM_Ctrl/S_AXI/Mem0 size [expr ${::AIT::spawnOutQueue_len}*8]]
 } else {
@@ -101,7 +100,12 @@ set addr_hwruntime_spawnOutQueue 0x0000000000000000
 set addr_hwcounter 0x0000000000000000
 
 set bitInfo_offset 0x20000
-set addr [expr $bitInfo_offset + 4096]
+set managed_reset_offset 0x21000
+if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
+    set addr 0x0
+} elseif {${::AIT::arch_device} eq "alveo"} {
+    set addr [expr $bitInfo_offset + 8192]
+}
 for {set i 0} {$i < [llength $bd_addr_segments]} {incr i} {
     set cur_dict [lindex $bd_addr_segments $i]
     set size [dict get $cur_dict size]
@@ -126,8 +130,6 @@ for {set i 0} {$i < [llength $bd_addr_segments]} {incr i} {
         set addr_hwruntime_spawnInQueue $format_addr
     } elseif {$name eq "spawnOutQueue"} {
         set addr_hwruntime_spawnOutQueue $format_addr
-    } elseif {$name eq "hwruntime_rst"} {
-        set addr_hwruntime_rst $format_addr
     } elseif {$name eq "hwcounter"} {
         set addr_hwcounter $format_addr
     }
@@ -135,9 +137,11 @@ for {set i 0} {$i < [llength $bd_addr_segments]} {incr i} {
 }
 
 if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
-    variable addr_bitInfo "0x0000000080020000"
+    variable addr_bitInfo [format 0x%016x [expr "0x0000000080000000" + $bitInfo_offset]]
+    variable addr_managed_reset [format 0x%016x [expr "0x0000000080000000" + $managed_reset_offset]]
 } elseif {${::AIT::arch_device} eq "alveo"} {
     variable addr_bitInfo [format 0x%016x [expr [dict get ${::AIT::address_map} "ompss_base_addr"] + $bitInfo_offset]]
+    variable addr_managed_reset [format 0x%016x [expr [dict get ${::AIT::address_map} "ompss_base_addr"] + $managed_reset_offset]]
 }
 
 # Create project and set board files
@@ -155,7 +159,7 @@ set_property ip_repo_paths HLS [current_project]
 set_property sim.ip.auto_export_scripts false [current_project]
 
 # If enabled, set cache location
-if {${::AIT::IP_caching}} {
+if ${::AIT::IP_caching} {
     check_ip_cache -import_from_project -use_cache_location ${::AIT::path_CacheLocation}
 }
 
@@ -174,9 +178,6 @@ if {[file isdirectory IPs]} {
     foreach {IP} [glob -nocomplain IPs/*.{v,vhdl}] {
         import_files -norecurse $IP
     }
-    foreach {IP} [glob -nocomplain IPs/hwruntime/*/*.zip] {
-        update_ip_catalog -add_ip $IP -repo_path IPs
-    }
     update_ip_catalog
 }
 
@@ -214,19 +215,9 @@ if {[file exists tcl/scripts/userPreDesign.tcl]} {
 # Add required common IPs
 AIT::board::init_bd
 
-if {${::AIT::hwruntime} eq "fom"} {
-    variable name_hwruntime Fast_OmpSs_Manager
-} elseif {${::AIT::hwruntime} eq "som"} {
-    variable name_hwruntime Smart_OmpSs_Manager
-} elseif {${::AIT::hwruntime} eq "pom"} {
-    variable name_hwruntime Picos_OmpSs_Manager
-}
-
-variable hwruntime_template tcl/templates/hwruntime/${::AIT::hwruntime}/$name_hwruntime.tcl
-
 # Add OmpSs Manager template
-if {[catch {source -notrace $hwruntime_template}]} {
-    AIT::error_msg "Failed sourcing $name_hwruntime template"
+if {[catch {source -notrace tcl/templates/Picos_OmpSs_Manager.tcl}]} {
+    AIT::error_msg "Failed sourcing Picos_OmpSs_Manager template"
 }
 
 if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
@@ -238,8 +229,9 @@ if {(${::AIT::arch_device} eq "zynq") || (${::AIT::arch_device} eq "zynqmp")} {
 AIT::board::connect_clock [get_bd_pins Hardware_Runtime/aclk]
 AIT::board::connect_reset [get_bd_pins Hardware_Runtime/interconnect_aresetn] "interconnect"
 AIT::board::connect_reset [get_bd_pins Hardware_Runtime/peripheral_aresetn] "peripheral"
+connect_bd_net [get_bd_pins Hardware_Runtime/managed_aresetn] [get_bd_pins reset_AND/Res]
 
-if {${::AIT::advanced_hwruntime}} {
+if ${::AIT::task_creation} {
     # Add the second port to bitInfo and connect it to OmpSs Manager
     set_property -dict [list CONFIG.Memory_Type {True_Dual_Port_RAM} CONFIG.Register_PortA_Output_of_Memory_Primitives {false} CONFIG.Register_PortB_Output_of_Memory_Primitives {false}] [get_bd_cells bitInfo]
     connect_bd_intf_net -boundary_type upper [get_bd_intf_pins Hardware_Runtime/bitInfo] [get_bd_intf_pins bitInfo/BRAM_PORTB]
@@ -267,7 +259,7 @@ set accID 0
 set axi_ports []
 
 foreach acc ${::AIT::accs} {
-    lassign [split $acc ":"] accHash accNumInstances accName  taskCreator
+    lassign [split $acc ":"] accHash accNumInstances accName taskCreator
 
     set accName_long ${accName}_ompss
 
@@ -287,7 +279,7 @@ foreach acc ${::AIT::accs} {
 
         # Connect clk and rst pins
         AIT::board::connect_clock [get_bd_pins ${accName}_${instanceNum}/aclk]
-        connect_bd_net [get_bd_pins ${accName}_${instanceNum}/managed_aresetn] [get_bd_pins Hardware_Runtime/managed_aresetn]
+        connect_bd_net [get_bd_pins ${accName}_${instanceNum}/managed_aresetn] [get_bd_pins reset_AND/Res]
 
         ## AXI interfaces
         # Get list of M_AXI interfaces
@@ -338,7 +330,7 @@ foreach acc ${::AIT::accs} {
         }
 
         # If this is a task creator, instantiate the newtask_spawner
-        if {$taskCreator} {
+        if $taskCreator {
             if {[get_bd_intf_pins -quiet -regexp ${accName}_${instanceNum}/$accName_long/mcxx_spawnInPort(_V)*?] ne ""} {
                 set acc_spawnInStream [get_bd_intf_pins -regexp ${accName}_${instanceNum}/$accName_long/mcxx_spawnInPort(_V)*?]
             } elseif {[get_bd_pins -quiet -regexp ${accName}_${instanceNum}/$accName_long/mcxx_spawnInPort(_V)*?] ne ""} {
@@ -443,7 +435,7 @@ foreach port $axi_ports {
 
     # Mark AXI port for debug
     if {(${::AIT::debugInterfaces} eq "AXI") || (${::AIT::debugInterfaces} eq "both")} {
-        AIT::AXI::mark_debug $port
+        AIT::AXI::mark_debug [get_bd_intf_pins $port]
     }
 }
 save_bd_design
@@ -479,7 +471,7 @@ if {${::AIT::hwcounter} || ${::AIT::hwinst}} {
 
     AIT::board::connect_clock [get_bd_pins HW_Counter/s_axi_aclk]
 
-    if {${::AIT::hwinst}} {
+    if ${::AIT::hwinst} {
         set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<0]]
     }
     set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<1]]
@@ -536,22 +528,19 @@ foreach bd_addr_seg $bd_addr_segments {
     assign_bd_address [get_bd_addr_segs $bd_seg_name] -range $range -offset $addr
 }
 
-if {${::AIT::advanced_hwruntime}} {
+if ${::AIT::task_creation} {
     set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<7]]
 }
 
-if {${::AIT::hwruntime} eq "som"} {
-    set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<8]]
-} elseif {${::AIT::hwruntime} eq "pom"} {
-    set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<9]]
-}
+set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<9]]
 
-if {${::AIT::simplify_interconnection}} {
+if ${::AIT::simplify_interconnection} {
     set bitmap_bitInfo [format 0x%08x [expr $bitmap_bitInfo | 0x1<<3]]
 }
 
 if {(${::AIT::arch_device} ne "simulation") && (${::AIT::arch_device} ne "shell")} {
     assign_bd_address [get_bd_addr_segs *bitInfo_BRAM_Ctrl*] -range 4K -offset $addr_bitInfo
+    assign_bd_address [get_bd_addr_segs *managed_reset*] -range 4K -offset $addr_managed_reset
 }
 
 AIT::board::configure_address_map
@@ -614,15 +603,15 @@ append bitInfo_coe [format %08x ${::AIT::spawnInQueue_len}]\n
 append bitInfo_coe [string range $addr_hwruntime_spawnOutQueue 10 17]\n
 append bitInfo_coe [string range $addr_hwruntime_spawnOutQueue 2 9]\n
 append bitInfo_coe [format %08x ${::AIT::spawnOutQueue_len}]\n
-append bitInfo_coe [string range $addr_hwruntime_rst 10 17]\n
-append bitInfo_coe [string range $addr_hwruntime_rst 2 9]\n
+append bitInfo_coe [string range $addr_managed_reset 10 17]\n
+append bitInfo_coe [string range $addr_managed_reset 2 9]\n
 append bitInfo_coe [string range $addr_hwcounter 10 17]\n
 append bitInfo_coe [string range $addr_hwcounter 2 9]\n
 append bitInfo_coe $xtasks_bin_str
 append bitInfo_coe "FFFFFFFF\n"
 append bitInfo_coe [AIT::ascii2hex ${::AIT::ait_call}\n]
 append bitInfo_coe "FFFFFFFF\n"
-set hwruntime_vlnv [get_property VLNV [get_bd_cells /Hardware_Runtime/$name_hwruntime]]
+set hwruntime_vlnv [get_property VLNV [get_bd_cells /Hardware_Runtime/Picos_OmpSs_Manager]]
 append bitInfo_coe [AIT::ascii2hex $hwruntime_vlnv\n]
 append bitInfo_coe "FFFFFFFF\n"
 append bitInfo_coe [AIT::ascii2hex ${::AIT::bitInfo_note}\n]
@@ -664,7 +653,7 @@ if {[file exists tcl/scripts/userPostDesign.tcl]} {
 }
 
 # If enabled, configure register slices on AXI Interconnects
-if {${::AIT::interconRegSlice_all}} {
+if ${::AIT::interconRegSlice_all} {
     set interconnects [get_bd_cells -hierarchical -regexp -filter {VLNV =~ xilinx.com:ip:axi_interconnect.*} .*]
 
     foreach inter $interconnects {
@@ -675,7 +664,7 @@ if {${::AIT::interconRegSlice_all}} {
             set_property -dict [list CONFIG.S[format %02u $i]_HAS_REGSLICE {4}] [get_bd_cells $inter]
         }
     }
-} elseif {${::AIT::interconRegSlice_mem}} {
+} elseif ${::AIT::interconRegSlice_mem} {
     set interconnects [get_bd_cells -hierarchical -regexp -filter {VLNV =~ xilinx.com:ip:axi_interconnect.* && NAME =~ {.*(data|control|coherent|master).*}} .*]
 
     foreach inter $interconnects {
